@@ -17,15 +17,12 @@
 
 #include <purpose/pluginbase.h>
 #include <QDebug>
-#include <QTimer>
+#include <QUrl>
 #include <QStandardPaths>
-#include <QJsonDocument>
-#include <QJsonObject>
 #include <QJsonArray>
 #include <KLocalizedString>
 #include <KPluginFactory>
 #include <KJob>
-#include <KJobTrackerInterface>
 #include <KIO/TransferJob>
 #include <KIO/StoredTransferJob>
 
@@ -47,7 +44,7 @@ class PastebinJob : public Purpose::Job
 
         void start() override
         {
-            QJsonArray urls = data().value(QStringLiteral("urls")).toArray();
+            const QJsonArray urls = data().value(QStringLiteral("urls")).toArray();
 
             if (urls.isEmpty()) {
                 qWarning() << "no urls to share" << urls << data();
@@ -56,7 +53,7 @@ class PastebinJob : public Purpose::Job
             }
 
             m_pendingJobs = 0;
-            foreach(const QJsonValue &val, urls) {
+            for (const QJsonValue &val : urls) {
                 QString u = val.toString();
                 KIO::StoredTransferJob* job = KIO::storedGet(QUrl(u), KIO::NoReload, KIO::HideProgressInfo);
                 connect(job, &KJob::finished, this, &PastebinJob::fileFetched);
@@ -92,7 +89,7 @@ class PastebinJob : public Purpose::Job
             QByteArray bytearray = "api_option=paste&api_paste_private=1&api_paste_name=kde-purpose-pastebin-plugin&api_paste_expire_date=1D&api_paste_format=diff&api_dev_key="+*apiKey+"&api_paste_code=";
             bytearray += QUrl::toPercentEncoding(QString::fromUtf8(m_data));
 
-            const QUrl url(QStringLiteral("http://pastebin.com/api/api_post.php"));
+            const QUrl url(QStringLiteral("https://pastebin.com/api/api_post.php"));
 
             KIO::TransferJob *tf = KIO::http_post(url, bytearray);
 
