@@ -18,8 +18,6 @@
 #include <purpose/pluginbase.h>
 #include <QDebug>
 #include <QProcess>
-#include <QJsonDocument>
-#include <QJsonObject>
 #include <QJsonArray>
 #include <QStandardPaths>
 #include <KPluginFactory>
@@ -28,6 +26,7 @@
 #include <KShell>
 #include <KLocalizedString>
 #include <QTimer>
+#include <QUrl>
 #include "debug.h"
 
 Q_LOGGING_CATEGORY(PLUGIN_TELEGRAM, "org.kde.purpose.plugin.telegram")
@@ -45,10 +44,10 @@ class TelegramJob : public Purpose::Job
         QStringList arrayToList(const QJsonArray& array)
         {
             QStringList ret;
-            foreach(const QJsonValue& val, array) {
+            for (const QJsonValue& val : array) {
                 QUrl url(val.toString());
                 if(url.isLocalFile()) {
-                    ret += url.toLocalFile();
+                    ret += KShell::quoteArg(url.toLocalFile());
                 }
             }
             return ret;
@@ -56,7 +55,7 @@ class TelegramJob : public Purpose::Job
 
         void start() override
         {
-            for (const QString &desktopFile: {QStringLiteral("org.telegram.desktop.desktop"), QStringLiteral("telegramdesktop.desktop") }) {
+            for (const QString &desktopFile: {QStringLiteral("org.telegram.desktop.desktop"), QStringLiteral("telegramdesktop.desktop"), QStringLiteral("telegram-desktop.desktop") }) {
                 const auto path = QStandardPaths::locate(QStandardPaths::ApplicationsLocation, desktopFile);
                 if (!path.isEmpty()) {
                     useDesktopFile(path);
