@@ -30,18 +30,27 @@ class Purpose::MenuPrivate : public QObject
 {
 Q_OBJECT
 public:
-    ~MenuPrivate() { m_engine->deleteLater(); }
     MenuPrivate(Menu* q)
         : QObject(q)
-        , m_engine(new QQmlApplicationEngine)
         , m_model(new AlternativesModel(q))
         , q(q)
     {
-        m_engine->rootContext()->setContextObject(new KLocalizedContext(this));
-        m_engine->load(QUrl(QStringLiteral("qrc:/JobDialog.qml")));
+
+    }
+
+    ~MenuPrivate() override {
+        if (m_engine) {
+            m_engine->deleteLater();
+        }
     }
 
     void trigger(int row) {
+        if (!m_engine) {
+            m_engine = new QQmlApplicationEngine;
+            m_engine->rootContext()->setContextObject(new KLocalizedContext(this));
+            m_engine->load(QUrl(QStringLiteral("qrc:/JobDialog.qml")));
+        }
+
         Q_ASSERT(!m_engine->rootObjects().isEmpty());
         QObject* o = m_engine->rootObjects().at(0);
 
@@ -49,14 +58,16 @@ public:
             qWarning() << Q_FUNC_INFO << "object is NULL at m_engine" << m_engine << "rootObjects=" << m_engine->rootObjects();
             return;
         }
-        o->setProperty("configuration", QVariant::fromValue<QObject*>(m_model->configureJob(row)));
+        auto config = m_model->configureJob(row);
+        config->setUseSeparateProcess(false);
+        o->setProperty("configuration", QVariant::fromValue<QObject*>(config));
         o->setProperty("q", QVariant::fromValue<QObject*>(q));
         o->setProperty("visible", true);
         o->setParent(q);
     }
 
 public:
-    QQmlApplicationEngine* m_engine;
+    QQmlApplicationEngine* m_engine = nullptr;
     QPointer<AlternativesModel> m_model;
     Purpose::Menu* q;
 };
@@ -78,7 +89,7 @@ void Menu::reload()
     clear();
     for(int i=0, c=d->m_model->rowCount(); i != c; ++i) {
         QModelIndex idx = d->m_model->index(i);
-        QAction* a = addAction(idx.data(Qt::DisplayRole).toString());
+        QAction* a = addAction(idx.data(AlternativesModel::ActionDisplayRole).toString());
         a->setToolTip(idx.data(Qt::ToolTipRole).toString());
         a->setIcon(idx.data(Qt::DecorationRole).value<QIcon>());
         a->setProperty("pluginId", idx.data(AlternativesModel::PluginIdRole));
